{% extends "core_main_app/_render/admin/theme/tools/section.html" %}
{% load static %}

{% block section_title %}Configure Templates{% endblock %}

{% block section_content %}
  <div class="row">
      <div class="col-md-12">
        {% include 'core_elasticsearch_app/admin/templates/list/list_base.html' %}
      </div>
  </div>
{% endblock %}
