.es_search_box_input {
    z-index: 1000;
}

.es_item_title em{
    color: GoldenRod;
}

.es_item_description em{
    color: DarkCyan;
}

.es_item_title{
    font-weight: bold;
}

.es_item_description{
    font-size: 0.8em;
}

.ui-autocomplete {
    z-index:1000;
}

.ui-autocomplete .ui-menu-item .ui-menu-item-wrapper.ui-state-active {
   background-color: GhostWhite;
   color: black;
}

.es_search_icon {
    cursor: pointer;
}