{% load static %}
<script src="{% static 'core_explore_common_app/common/js/tools.js' %}"></script>
<script src="{% static 'core_elasticsearch_app/js/search_box.js' %}"></script>
<link rel="stylesheet" type="text/css" href="{% static 'core_elasticsearch_app/css/search_box.css' %}">


<form class="form-inline mr-auto">
  <div class="md-form my-0">
    <input id="es_search_box_input" class="form-control es_search_box_input hidden" type="text"
           placeholder="Search..." aria-label="Search">
    <i class="es_search_icon fas fa-search text-white ml-3" aria-hidden="true"></i>
  </div>
</form>

